Module proptest_arbitrary::bits [] [src]

Arbitrary implementations for integral types as bit patterns.

Structs

Bits

Bits is a simple newtype for treating the generic type parameter T as a set of bits for the purposes of production of arbitrary values.

Enums

BitsParams

Parameters for configuring the generation of StrategyFor<Bits<A>>.

Traits

AllOnes

Yields the "all ones" bit pattern for self for types which have such a notion.