prob

Function prob 

pub fn prob<X: Into<Probability>>(from: X) -> Probability
Creates a Probability from some value that is convertible into it.

Safety

Panics if the converted to probability would lie outside interval [0.0, 1.0]. Consult the Into (or From) implementation for more details.