Generator

Struct Generator 

pub struct Generator<V, F: Fn() -> V> { /* private fields */ }
Strategy for generating Vs from an Fn() -> V. It’s not a very interesting Strategy, but required sometimes when the only means of creating an object of some type is via a function while type type is also not Clone.

Implementations

Source

impl<V, F: Fn() -> V> Generator<V, F>

pub fn new(generator: F) -> Self

Constructs a Generator strategy.