SizeBounds

Struct SizeBounds 

pub struct SizeBounds(/* private fields */);
The minimum and maximum bounds on the size of a collection. The interval must form a subset of [0, std::usize::MAX).

Implementations

Source

impl SizeBounds

pub fn new(range: Range<usize>) -> Self

Creates a SizeBounds from a Range<usize>.

pub fn with<X>(self, and: X) -> HCons<Self, HCons<X, HNil>>

Merges self together with some other argument producing a product type expected by some impelementations of A: Arbitrary<'a> in A::Parameters. This can be more ergonomic to work with and may help type inference.

pub fn lift<X: Default>(self) -> HCons<Self, HCons<X, HNil>>

Merges self together with some other argument generated with a default value producing a product type expected by some impelementations of A: Arbitrary<'a> in A::Parameters. This can be more ergonomic to work with and may help type inference.