ParamsFor

Type Alias ParamsFor 

pub type ParamsFor<A> = ParamsType<'static, A>;
ParamsFor allows you to mention the type of Parameters for the input type A without directly using associated types or without resorting to existential types. This way, if implementation of Arbitrary changes, your tests should not break. Additionally, if you have a custom Arbitrary::Parameters type, or use a Arbitrary::Parameters type with generics in it where you’ve provided a custom type for the type parameter, you need not export your type if A is Arbitrary as the Parameters type is still reachable from ParamsFor.

This is the same as ParamsType<'static, A>.