Struct proptest_arbitrary::bits::Bits
[−]
[src]
pub struct Bits<T: BitSetLike>(_);
Bits is a simple newtype for treating the generic type parameter T as
a set of bits for the purposes of production of arbitrary values.
Methods
impl<T: BitSetLike> Bits<T>[src]