pub struct Generator<V, F: Fn() -> V> { /* private fields */ }Expand description
Strategy for generating Vs from an Fn() -> V.
It’s not a very interesting Strategy, but required sometimes
when the only means of creating an object of some type is
via a function while type type is also not Clone.
Implementations