Struct proptest_arbitrary::Probability
[−]
[src]
pub struct Probability(_);
A probability in the range [0.0, 1.0] with a default of 0.5.
Methods
impl Probability[src]
fn new(prob: f64) -> Self[src]
fn with<X>(self, and: X) -> HCons<Self, HCons<X, HNil>>[src]
Merges self together with some other argument producing a product
type expected by some impelementations of A: Arbitrary<'a> in
A::Parameters. This can be more ergonomic to work with and may
help type inference.
fn lift<X: Default>(self) -> HCons<Self, HCons<X, HNil>>[src]
Merges self together with some other argument generated with a
default value producing a product type expected by some
impelementations of A: Arbitrary<'a> in A::Parameters.
This can be more ergonomic to work with and may help type inference.