pub struct SizeBounds(/* private fields */);Expand description
The minimum and maximum bounds on the size of a collection.
The interval must form a subset of [0, std::usize::MAX).
Implementations
Sourceimpl SizeBounds
impl SizeBounds
Sourcepub fn with<X>(self, and: X) -> HCons<Self, HCons<X, HNil>>
pub fn with<X>(self, and: X) -> HCons<Self, HCons<X, HNil>>
Merges self together with some other argument producing a product
type expected by some impelementations of A: Arbitrary<'a> in
A::Parameters. This can be more ergonomic to work with and may
help type inference.
Sourcepub fn lift<X: Default>(self) -> HCons<Self, HCons<X, HNil>>
pub fn lift<X: Default>(self) -> HCons<Self, HCons<X, HNil>>
Merges self together with some other argument generated with a
default value producing a product type expected by some
impelementations of A: Arbitrary<'a> in A::Parameters.
This can be more ergonomic to work with and may help type inference.