Struct proptest_arbitrary::SizeBounds
[−]
[src]
pub struct SizeBounds(_);
The minimum and maximum bounds on the size of a collection.
The interval must form a subset of [0, std::usize::MAX).
Methods
impl SizeBounds[src]
fn new(range: Range<usize>) -> Self[src]
Creates a SizeBounds from a Range<usize>.
fn with<X>(self, and: X) -> HCons<Self, HCons<X, HNil>>[src]
Merges self together with some other argument producing a product
type expected by some impelementations of A: Arbitrary<'a> in
A::Parameters. This can be more ergonomic to work with and may
help type inference.
fn lift<X: Default>(self) -> HCons<Self, HCons<X, HNil>>[src]
Merges self together with some other argument generated with a
default value producing a product type expected by some
impelementations of A: Arbitrary<'a> in A::Parameters.
This can be more ergonomic to work with and may help type inference.